<?php

/**
 * Display information about all the mod_labnbook modules in the requested course.
 *
 * @copyright   2019 Université Grenoble Alpes
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
require(__DIR__ . '/../../config.php');
require_once(__DIR__ . '/lib.php');

$id = required_param('id', PARAM_INT);

$course = $DB->get_record('course', ['id' => $id], '*', MUST_EXIST);
require_course_login($course);

$coursecontext = context_course::instance($course->id);

$event = \mod_labnbook\event\course_module_instance_list_viewed::create([
    'context' => $modulecontext,
]);
$event->add_record_snapshot('course', $course);
$event->trigger();

$PAGE->set_url('/mod/labnbook/index.php', ['id' => $id]);
$PAGE->set_title(format_string($course->fullname));
$PAGE->set_heading(format_string($course->fullname));
$PAGE->set_context($coursecontext);

$labnbooks = get_all_instances_in_course('labnbook', $course);

echo $OUTPUT->header();
echo $OUTPUT->heading(get_string('modulenameplural', 'mod_labnbook'));

if (empty($labnbooks)) {
    notice(get_string('nonewmodules', 'mod_labnbook'), new moodle_url('/course/view.php', ['id' => $course->id]));
}

$table = new html_table();
$table->attributes['class'] = 'generaltable mod_index';
if ($course->format == 'weeks') {
    $table->head  = [get_string('week'), get_string('name')];
    $table->align = ['center', 'left'];
} elseif ($course->format == 'topics') {
    $table->head  = [get_string('topic'), get_string('name')];
    $table->align = ['center', 'left', 'left', 'left'];
} else {
    $table->head  = [get_string('name')];
    $table->align = ['left', 'left', 'left'];
}
foreach ($labnbooks as $labnbook) {
    if (!$labnbook->visible) {
        $link = html_writer::link(
            new moodle_url('/mod/labnbook/view.php', ['id' => $labnbook->coursemodule]),
            format_string($labnbook->name, true),
            ['class' => 'dimmed']
        );
    } else {
        $link = html_writer::link(
            new moodle_url('/mod/labnbook/view.php', ['id' => $labnbook->coursemodule]),
            format_string($labnbook->name, true)
        );
    }

    if ($course->format === 'weeks' || $course->format === 'topics') {
        $table->data[] = [$labnbook->section, $link];
    } else {
        $table->data[] = [$link];
    }
}
echo html_writer::table($table);

echo $OUTPUT->footer();
