<?php

/**
 * Inner HTL page.
 * Bind a Moodle user to a LabNbook account.
 *
 * @copyright   2019 Université Grenoble Alpes
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
use mod_labnbook\fetch;
use mod_labnbook\local\helper;

require_once \dirname(__DIR__, 2) . '/config.php';
require_once(__DIR__ . '/lib.php');

$return = required_param('return', PARAM_RAW);
$returnUrl = \base64_decode($return);
$courseid = required_param('courseid', PARAM_INT);
$id = required_param('id', PARAM_INT);

if ($id) {
    $cm             = get_coursemodule_from_id("labnbook", $id, 0, false, MUST_EXIST);
    $course         = $DB->get_record('course', ['id' => $cm->course], '*', MUST_EXIST);
    $moduleinstance = $DB->get_record(LABNBOOK_TABLE, ['id' => $cm->instance], '*', MUST_EXIST);
    unset($id);

    $modulecontext = context_module::instance($cm->id);
    $title = $moduleinstance->name;
} else {
    $course = $DB->get_record('course', ['id' => $courseid], '*', MUST_EXIST);
    $modulecontext = context_course::instance($courseid);
    $title = $course->fullname;
    $cm = null;
}
require_login($course, true, $cm);
$PAGE->set_url('/mod/labnbook/user_binding.php', ['courseid' => $courseid, 'return' => $return]);
$PAGE->set_title(format_string($title));
$PAGE->set_heading(format_string($course->fullname));
$PAGE->set_context($modulecontext);

$fetchInstitution = new fetch\institution();
$context = context_course::instance($courseid);
$isTeacher = has_capability('mod/labnbook:addinstance', $context);
$role = ($isTeacher ? 'teacher' : 'learner');
global $USER;
$url = $fetchInstitution->getRedirectUrl();
if (false !== strpos($returnUrl, helper::localUrlPrefix)) {
    $actual_link = str_replace(helper::localUrlPrefix, '', $returnUrl);
} else {
    $actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$returnUrl";
}
$token=$fetchInstitution->getBindingTokenForRedirect($actual_link, $role, $USER);

echo $OUTPUT->header();
$templateData = [
    "url" => $url."?token=".$token,
];
echo $OUTPUT->render_from_template("mod_labnbook/view_bind", $templateData);
echo $OUTPUT->footer();
